@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 from .classification_dataset import ClassificationDataset
 from .nlp_dataset import NLPDataset
+from .bert_classification_dataset import BertClassificationDataset
 
 
 __all__ = [
-    'NLPDataset', 'ClassificationDataset'
+    'NLPDataset', 'ClassificationDataset', 'BertClassificationDataset'
 ]
