@@ -5,7 +5,7 @@ import pandas as pd
 
 from sknlp.layers import MLPLayer
 from sknlp.vocab import Vocab
-from sknlp.data.bert_dataset import BertClassificationDataset
+from sknlp.data import BertClassificationDataset
 from ..text2vec import Bert2vec
 from .deep_classifier import DeepClassifier
 
